/**************************************************************** 
 * Description: 
 * Author: Alex Li
 * Date: 2024-08-09 21:19:17
 * LastEditTime: 2024-08-19 23:28:43
****************************************************************/
#include <iostream>
using namespace std;
#define ll long long  // 定义长整型别名

// 声明全局变量
ll n, q, x, y, s;
ll tree[500001];  // 树状数组，最多支持 500000 个元素

// 计算一个数的最低位 1 的值，即 lowbit 函数
ll lowbit(ll num) {
    return num & -num;
}

// 更新树状数组中指定位置的值
void update(ll index, ll delta) {
    while (index <= n) {
        tree[index] += delta;
        index += lowbit(index);
    }
}

// 查询前缀和，即树状数组中从 1 到 index 的所有元素的和
ll query(ll index) {
    ll sum = 0;
    while (index > 0) {
        sum += tree[index];
        index -= lowbit(index);
    }
    return sum;
}

int main() {
    cin >> n >> q;  // 读取数列长度 n 和操作次数 q
    ll initial_val, prev_val = 0;

    // 初始化树状数组，直接根据差分数组构建
    for (int i = 1; i <= n; i++) {
        cin >> initial_val;  // 读取每个数列元素的初始值
        update(i, initial_val - prev_val);  // 插入差分值
        prev_val = initial_val;  // 更新 prev_val 为当前值
    }

    // 处理每个操作
    for (int i = 0; i < q; i++) {
        cin >> s;  // 读取操作类型
        if (s == 1) {  // 如果是操作1，进行区间加法
            cin >> x >> y >> s;
            update(x, s);  // 将区间 [x, y] 内的每个数加上 s
            update(y + 1, -s);  // 调整区间外的值以维持差分数组
        } else if (s == 2) {  // 如果是操作2，查询某个数的值
            cin >> x;
            cout << query(x) << endl;  // 输出第 x 个数的当前值
        }
    }

    return 0;
}
